#!/bin/bash
#
# Copyright (c) 2011 SUSE Linux Products GmbH
#
# This software is licensed to you under the GNU General Public License,
# version 2 (GPLv2). There is NO WARRANTY for this software, express or
# implied, including the implied warranties of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE. You should have received a copy of GPLv2
# along with this software; if not, see
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.txt.

RNC=$1
PROFILE=$2
EXITCODE=0

function usage () {
    echo "usage $0 rncfile profile";
    exit 1
}

if [ -z "$RNC" -o ! -f "$RNC" ]; then
    echo "Missing schema file";
    usage
fi

if [ -z "$PROFILE" -o ! -f "$PROFILE" ]; then
    echo "Missing profile file";
    usage
fi

echo -e -n "Checking Profile: $PROFILE\t\t"

if grep "BEGIN PGP SIGNED MESSAGE" $PROFILE >/dev/null 2>&1; then
    TMP=`mktemp --dry-run -t rnc-profile.XXXXXXXXXX`
    gpg -d --skip-verify --output $TMP $PROFILE 2>/dev/null
    OUT=`jing -c $RNC $TMP`
    if echo "$OUT" | grep -i "error" 1>/dev/null 2>&1; then
	echo "[FAILED]"
	echo -e "$OUT"
	EXITCODE=1
    else
	echo "[OK]"
    fi
    rm -f $TMP
else
    OUT=`jing -c $RNC $PROFILE`
    if echo "$OUT" | grep -i "error" 1>/dev/null 2>&1; then
        echo "[FAILED]"
	echo -e "$OUT"
	EXITCODE=1
    else
        echo "[OK]"
    fi
fi

exit $EXITCODE

