#!/usr/bin/perl -w
#
# Copyright (c) 2011-2014 SUSE Linux Products GmbH
#
# This software is licensed to you under the GNU General Public License,
# version 2 (GPLv2). There is NO WARRANTY for this software, express or
# implied, including the implied warranties of MERCHANTABILITY or FITNESS
# FOR A PARTICULAR PURPOSE. You should have received a copy of GPLv2
# along with this software; if not, see
# http://www.gnu.org/licenses/old-licenses/gpl-2.0.txt.

#
# test lscpu command
#

use strict;
use File::Basename;

BEGIN {
    my $app  = dirname($0)."/..";
    unshift @INC, "$app";
}
my $testdir = dirname($0);

if( ! -d "$testdir/x86_64-64cpu" )
{
    `tar -x -v -C $testdir -f $testdir/x86_64-64cpu.tar.gz`;
}

my $out = `/usr/bin/lscpu -s $testdir/x86_64-64cpu/`;
exit 1 if($? != 0 || $out eq "");

my $threadspc = 0;
my $coresps = 0;
my $sockets = 0;

foreach my $line (split(/\n/, $out))
{
    if($line =~ /^Thread.+per\score:\s*(\d+)\s*$/)
    {
        $threadspc = int($1);
    }
    if($line =~ /^Core.+per\ssocket:\s*(\d+)\s*$/)
    {
        $coresps = int($1);
    }
    if($line =~ /^Socket.+:\s*(\d+)\s*$/)
    {
        $sockets = int($1);
    }
}

if( $testdir && -d "$testdir/x86_64-64cpu" )
{
    `rm -rf $testdir/x86_64-64cpu`;
}
if($threadspc == 2 && $coresps == 8 && $sockets == 4)
{
    exit 0;
}
else
{
    print STDERR "Expecting (threads/cores/sockets): 2 == $threadspc / 8 == $coresps / 4 == $sockets\n";
    exit 1;
}
